---
title: '[중요/공지] 주요 웹 브라우저의 TLS1.0 및 TLS1.1 지원 종료 안내 '
category: 공지사항
tags:
  - 공통
  - 공지사항
datetime: 2021-11-02T15:00:00.000Z
---

안녕하세요! 포트원 입니다.

주요 웹 브라우저의 TLS1.0  및 TLS1.1 지원이 중단 될 예정으로 작업 내용 과 일정을 안내 드립니다.

현재 사용 가능한 TLS 버젼 중 **TLS 1.0 및 TLS 1.1 구 버젼 사용은 비활성화 하고 기본 설정이 TLS 1.2 이상 사용 되도록 프로토콜 변경 작업**이 아래와 같이 예정 되어 있음을 안내 드립니다.

※  TLS(Transport Layer Security)는SSLv3.0을 참고하여 RFC2246('1999)으로 표준화 된 통신용 암호화 프로토콜

<Callout title="작업 상세 내용" content="1. 작업 내용 : TLS 1.0 및 1.1 비활성화
2. 작업 사유 : 보다 안전한 통신 환경 조성 마련을 위해 TLS 버젼 기본 설정 업데이트
3. 작업 일시 : 2021년 11월 22일(월) 새벽 02시
4. 영향 범위 
▼ 아래 구 버전의 브라우저에서 아임포트 서비스 이용 불가  최신 브라우저 버전으로 업데이트 필요
- Android 4.3 버전 이하
- Chrome 29 버전 이하
- Firefox 26 버전 이하
- IE 10 버전 이하
- Opera 16 버전 이하
- Safari 6.0.4(OS X 10.8.4) 버전 이하
- 자바 7 이하, OpenSSL 0.9.8y 이하 버전" />
